@@ -34,7 +34,7 @@ class MediaStream(Base):
         self.default_resize = 800
         self.is_deletable = False
         self.session = requests.Session()
-
+        self.debug_filename = None 
               
         if logger:
             self.logger = logger
@@ -62,6 +62,7 @@ class MediaStream(Base):
             
             # we can either download the event, or access it via ZM
             # indirection 
+            self.debug_filename = '{}-image'.format(self.stream)
             if self.options.get('download'):
                 self.logger.Debug(1,'Downloading event:{}'.format(self.stream))
                 es = self.api.events({'event_id': int(self.stream)})
@@ -101,6 +102,9 @@ class MediaStream(Base):
     
         if (self.type=='video'):
             self.logger.Debug (1, 'Starting video stream {}'.format(stream))
+            f,_=os.path.splitext(os.path.basename(self.stream))
+            self.debug_filename = '{}-image'.format(f)
+
             self.fvs = FileVideoStream(self.stream).start()
             time.sleep(1)
             self.logger.Debug (2, 'First load - skipping to frame {}'.format(self.start_frame))
@@ -117,6 +121,8 @@ class MediaStream(Base):
         else:
             self.logger.Debug (2,'No need to start streams, we are picking images from {}'.format(self.stream))
 
+    def get_debug_filename(self):
+        return self.debug_filename
 
     def image_dimensions(self):
         return {
@@ -163,7 +169,7 @@ class MediaStream(Base):
             self.more_images_to_read = False
             if self.options.get('resize') != 'no':
                 frame = imutils.resize(frame,width=self.options.get('resize', self.default_resize))
-            self.resized_h_w = frame.shape[:2]            
+            self.resized_h_w = frame.shape[:2]  
             return frame
 
 
@@ -201,6 +207,12 @@ class MediaStream(Base):
                 frame = imutils.resize(frame,width=self.options.get('resize', self.default_resize))
             self.resized_h_w = frame.shape[:2]
 
+            if self.options.get('save_frames') and self.debug_filename:
+                d = self.options.get('save_frames_dir','/tmp')
+                fname = '{}/{}-{}.jpg'.format(d,self.debug_filename,self.last_frameid_read) 
+                self.logger.Debug (4, 'Saving image to {}'.format(fname))
+                cv2.imwrite(fname,frame)        
+
             return frame
         
         else: # image
@@ -211,10 +223,23 @@ class MediaStream(Base):
             
             self.logger.Debug (3, 'Reading {}'.format(url))
             response = None
-            if self.api:
-                response = self.api._make_request(url)
-            else:
-                response = self.session.get(url)
+            try:
+                if self.api:
+                    response = self.api._make_request(url)
+                else:
+                    response = self.session.get(url)
+            except Exception as e:
+                if self.frame_set:
+                    if self.next_frame_set_index < len(self.frame_set):
+                        self.logger.Error('Error reading frame: {}, but moving to next frame_set'.format(url))
+                        self.last_frameid_read = self.frame_set[self.next_frame_set_index]
+                        self.next_frame_set_index += 1
+                        return self.read()
+                    else:
+                        self.more_images_to_read = False
+                        self.next_frameid_to_read = 0
+                        return None 
+                        
             if self.frame_set:
                 self.last_frameid_read = self.frame_set[self.next_frame_set_index]
                 self.next_frame_set_index += 1
@@ -223,7 +248,7 @@ class MediaStream(Base):
                 self.next_frameid_to_read +=self.frame_skip
 
             self.frames_processed +=1 
-            if response.status_code == 200:
+            if response and response.status_code == 200:
                 try:
                     img = np.asarray(bytearray(response.content), dtype='uint8')
                     img = cv2.imdecode (img, cv2.IMREAD_COLOR)
@@ -232,10 +257,18 @@ class MediaStream(Base):
                     if self.options.get('resize') != 'no':
                         img = imutils.resize(img,width=self.options.get('resize', self.default_resize))
                     self.resized_h_w = img.shape[:2]
+
+                    if self.options.get('save_frames') and self.debug_filename:
+                        d = self.options.get('save_frames_dir','/tmp')
+                        fname = '{}/{}-{}.jpg'.format(d,self.debug_filename,self.last_frameid_read) 
+                        self.logger.Debug (4, 'Saving image to {}'.format(fname))
+                        cv2.imwrite(fname,img)        
+
                     return img
                 except Exception as e:
                     self.logger.Error ('Could not retrieve url {}: {}'.format(url,e))
                     return None
+          
             else:
                 self.more_images_to_read = False
                 self.next_frameid_to_read = 0
