@@ -10,6 +10,7 @@ from pyzm.helpers.Base import Base
 import pyzm.ml.object as  ObjectDetect
 import pyzm.ml.face as FaceDetect
 import pyzm.ml.alpr as AlprDetect
+import pyzm.helpers.utils as utils
 
 import re
 import datetime
@@ -31,7 +32,8 @@ class DetectSequence(Base):
                     options = {
                         'general': {
                             # sequence of models you want to run for every specified frame
-                            'model_sequence': 'object,face,alpr' 
+                            'model_sequence': 'object,face,alpr' ,
+
                         },
                     
                         # We now specify all the config parameters per model_sequence entry
@@ -62,7 +64,10 @@ class DetectSequence(Base):
                                 'object_labels': '/var/lib/zmeventnotification/models/yolov4/coco.names',
                                 'object_min_confidence': 0.3,
                                 'object_framework':'opencv',
-                                'object_processor': 'gpu'
+                                'object_processor': 'gpu',
+                                # These are optional below. Default is 416. Change if your model is trained for larger sizes
+                                'model_width': 416, 
+                                'model_height: 416
                             }]
                         },
 
@@ -274,10 +279,14 @@ class DetectSequence(Base):
                 - start_frame (int): Which frame to start analysis. Default 1.
                 - frame_skip: (int): Number of frames to skip in video (example, 3 means process every 3rd frame)
                 - max_frames (int): Total number of frames to process before stopping
-                - pattern (string): regexp for objects that will be matched. 'strategy' key below will be applied to only objects that match this pattern
-                - frame_set (string): comma separated frames to read. Example 'alarm,2,4,9,snapshot'
-                - strategy: (string): various conditions to stop matching as below
-               
+                - pattern (string): regexp for objects that will be matched. 'frame_strategy' key below will be applied to only objects that match this pattern
+                - frame_set (string): comma separated frames to read. Example 'alarm,21,31,41,snapshot'
+                  Note that if you are specifying frame IDs and using ZM, remember that ZM has a frame buffer
+                  Default is 20, I think. So you may want to start at frame 21.
+                - save_frames (boolean): If True, will save frames used in analysis. Default False
+                - save_analyzed_frames (boolean): If True, will save analyzed frames (with boxes). Default False
+                - save_frames_dir (string): Directory to save analyzed frames. Default /tmp
+                - frame_strategy: (string): various conditions to stop matching as below
                     - 'most_models': Match the frame that has matched most models (does not include same model alternatives) (Default)
                     - 'first': Stop at first match 
                     - 'most': Match the frame that has the highest number of detected objects
@@ -312,7 +321,7 @@ class DetectSequence(Base):
         
 
         self.stream_options = options
-        match_strategy = options.get('strategy', 'most_models')
+        frame_strategy = self.stream_options.get('frame_strategy', 'most_models' )
         all_matches = []
         matched_b = []
         matched_e = []
@@ -361,8 +370,8 @@ class DetectSequence(Base):
             _models_in_frame = []
 
             # For each frame, loop across all models
+            found = False
             for seq in self.model_sequence:
-            
                 self.logger.Debug(1,'============ Frame: {} Running {} model in sequence =================='.format(self.media.get_last_read_frame(),seq))
                 pre_existing_labels = self.ml_options.get(seq,{}).get('general',{}).get('pre_existing_labels')
                 if pre_existing_labels:
@@ -400,7 +409,6 @@ class DetectSequence(Base):
                        
                         _b,_l,_c = m.detect(image=frame)
                         self.logger.Debug(4,'This model iteration inside {} found: labels: {},conf:{}'.format(seq, _l, _c))
-
                     except Exception as e:
                         self.logger.Error ('Error running model: {}'.format(e))
                         self.logger.Debug(2,traceback.format_exc())
@@ -419,44 +427,61 @@ class DetectSequence(Base):
                         _l_best_in_same_model = _l
                         _c_best_in_same_model = _c
                         _e_best_in_same_model = _e
+                    if _l_best_in_same_model and self.stream_options.get('save_analyzed_frames') and self.media.get_debug_filename():
+                            d = self.stream_options.get('save_frames_dir','/tmp')
+                            f = '{}/{}-analyzed-{}.jpg'.format(d,self.media.get_debug_filename(), media.get_last_read_frame())
+                            self.logger.Debug (4, 'Saving analyzed frame: {}'.format(f))
+                            a = utils.draw_bbox(frame,_b_best_in_same_model,_l_best_in_same_model,_c_best_in_same_model,self.stream_options.get('polygons'))
+                            for _b in _e_best_in_same_model:
+                                cv2.rectangle(a, (_b[0], _b[1]), (_b[2], _b[3]),
+                                    (0,0,255), 1)
+                            cv2.imwrite(f,a)
                     if (same_model_sequence_strategy=='first') and len(_b):
                         self.logger.Debug(3, 'breaking out of same model loop, as matches found and strategy is "first"')
                         break
                 # end of same model sequence iteration
                 # at this state x_best_in_model contains the best match across 
                 # same model variations
-
-                _labels_in_frame.extend(_l_best_in_same_model)
-                _boxes_in_frame.extend(_b_best_in_same_model)
-                _confs_in_frame.extend(_c_best_in_same_model)
-                _error_boxes_in_frame.extend(_e_best_in_same_model)
-                _models_in_frame.append(seq)
+                if _l_best_in_same_model:
+                    found = True
+                    _labels_in_frame.extend(_l_best_in_same_model)
+                    _boxes_in_frame.extend(_b_best_in_same_model)
+                    _confs_in_frame.extend(_c_best_in_same_model)
+                    _error_boxes_in_frame.extend(_e_best_in_same_model)
+                    _models_in_frame.append(seq)
+                    if (frame_strategy == 'first'):
+                        self.logger.Debug (2, 'Breaking out of main model loop as strategy is first')
+                        break
+                else:
+                    self.logger.Debug(2,'We did not find any {} matches in frame: {}'.format(seq,self.media.get_last_read_frame()))
 
             # end of primary model sequence
-            all_matches.append (
-                {
-                    'frame_id': self.media.get_last_read_frame(),
-                    'boxes': _boxes_in_frame,
-                    'error_boxes': _error_boxes_in_frame,
-                    'labels': _labels_in_frame,
-                    'confidences': _confs_in_frame,
-                    'models': _models_in_frame
-                    
-                }
-            )
-            matched_images.append(frame.copy())
-            
-            if (match_strategy=='first'):
-                break
+            if found:
+                all_matches.append (
+                    {
+                        'frame_id': self.media.get_last_read_frame(),
+                        'boxes': _boxes_in_frame,
+                        'error_boxes': _error_boxes_in_frame,
+                        'labels': _labels_in_frame,
+                        'confidences': _confs_in_frame,
+                        'models': _models_in_frame
+                        
+                    }
+                )
+                matched_images.append(frame.copy())
+                if (frame_strategy == 'first'):
+                    self.logger.Debug(2,'Frame strategy is first, breaking out of frame loop')
+                    break
+                
+               
         # end of while media loop   
-        diff_time = (datetime.datetime.now() - start).microseconds / 1000
            
-        #print ('*********** MATCH_STRATEGY {}'.format(match_strategy))
+        #print ('*********** MATCH_STRATEGY {}'.format(model_match_strategy))
         for idx,item in enumerate(all_matches):
-            if  ((match_strategy == 'first') or 
-            ((match_strategy == 'most') and (len(item['labels']) > len(matched_l))) or
-            ((match_strategy == 'most_models') and (len(item['models']) > len(matched_models))) or
-            ((match_strategy == 'most_unique') and (len(set(item['labels'])) > len(set(matched_l))))):
+            if  ((frame_strategy == 'first') or 
+            ((frame_strategy == 'most') and (len(item['labels']) > len(matched_l))) or
+            ((frame_strategy == 'most_models') and (len(item['models']) > len(matched_models))) or
+            ((frame_strategy == 'most_unique') and (len(set(item['labels'])) > len(set(matched_l))))):
                 matched_b =item['boxes']
                 matched_e = item['error_boxes']
                 matched_c = item['confidences']
@@ -469,9 +494,11 @@ class DetectSequence(Base):
             for seq in self.model_sequence:
                 for m in self.models[seq]:
                     m.release_lock()
-            
+
+        diff_time= (datetime.datetime.now() - start)
+
         self.logger.Debug(
-            1,'detection (with image loads) took: {} milliseconds to process {}'.format(diff_time, stream))
+            1,'detection (with image loads) took: {}  to process {}'.format(diff_time, stream))
         self.media.stop()
 
         matched_data = {
