@@ -31,7 +31,7 @@ class Yolo(Base):
         self.lock_name='pyzm_'+self.processor+'_lock'
         self.logger.Debug (2,f'Semaphore: max:{self.lock_maximum}, name:{self.lock_name}, timeout:{self.lock_timeout}')
         self.lock = portalocker.BoundedSemaphore(maximum=self.lock_maximum, name=self.lock_name,timeout=self.lock_timeout)
-        self.model_height = self.options.get('model_width', 416)
+        self.model_height = self.options.get('model_height', 416)
         self.model_width = self.options.get('model_width', 416)
          
     def acquire_lock(self):
@@ -73,9 +73,9 @@ class Yolo(Base):
         self.net = cv2.dnn.readNet(self.options.get('object_weights'),
                                 self.options.get('object_config'))
         #self.net = cv2.dnn.readNetFromDarknet(config_file_abs_path, weights_file_abs_path)
-        diff_time = (datetime.datetime.now() - start).microseconds / 1000
+        diff_time = (datetime.datetime.now() - start)
         self.logger.Debug(
-            1,'Yolo initialization (loading model from disk) took: {} milliseconds'
+            1,'Yolo initialization (loading model from disk) took: {}'
             .format(diff_time))
         if self.processor == 'gpu':
             (maj, minor, patch) = cv2.__version__.split('.')
@@ -134,7 +134,7 @@ class Yolo(Base):
         if self.options.get('auto_lock',True):
             self.release_lock()
             self.logger.Debug(2,'detect lock released')
-        diff_time = (datetime.datetime.now() - start).microseconds / 1000
+        diff_time = (datetime.datetime.now() - start)
         self.logger.Debug(
             1,'YOLO detection took: {} milliseconds'.format(diff_time))
 
@@ -168,9 +168,9 @@ class Yolo(Base):
         start = datetime.datetime.now()
         indices = cv2.dnn.NMSBoxes(boxes, confidences, conf_threshold,
                                    nms_threshold)
-        diff_time = (datetime.datetime.now() - start).microseconds / 1000
+        diff_time = (datetime.datetime.now() - start)
         self.logger.Debug(
-            2,'YOLO NMS filtering took: {} milliseconds'.format(diff_time))
+            2,'YOLO NMS filtering took: {}'.format(diff_time))
 
         bbox = []
         label = []
